# Building an iFrame on Bullhorn App

## Creating a View Layout:

![image](https://user-images.githubusercontent.com/46778695/206200113-db710961-0597-41a7-afe4-d4970770e5d3.png)

In order to access the View Layout menu, you need to access Menu->Admin->View Layout


## Chosing the Private Label and Field Map Entity:
![image](https://user-images.githubusercontent.com/46778695/206200537-81f52c45-8806-4d9b-8af4-593231f2432c.png)

Choose your label and Field Map Entity. It can be a Job, a Candidate or a Placement. In our case it is a Job.
⚠️ If your entity is Job, don't forget to do all the steps again for Job II, Job III and Job IV.

## Setting up the iFrame:
![image](https://user-images.githubusercontent.com/46778695/206200796-3b9b990b-e5b5-454e-ac1a-a9758180cd62.png)

There is three ways to set up an iFrame on the Bullhorn app. It can be a Custom Tab, Custom Menu Action or a Custom List Button. In our case it is a custom tab called Matching that will appear on the Job submenu.
Chose name, click the enable box, enter the url and chose your user types !

## Using the iFrame:
![image](https://user-images.githubusercontent.com/46778695/206201147-ae04c375-994f-410e-927d-d6aae991050f.png)

You now have a Tab called Matching on the Job submenu. Click on it and the iFrame will run.
